@@ -81,9 +81,22 @@ def get_env(key, validate=env_has_k):
     """
     try:
         return validate(key, os.getenv(key))
+    except ProxyError:
+        raise
     except Exception, e:
         raise EnvError("error parsing env-var: %s: %s" % (key, e), e)
 
+class ProxyError(Exception):
+    """
+    Thrown when the proxy specifier is incomplete or corrupted.
+    """
+    def __init__(self, message=None, cause=None):
+        self.message = message
+        self.cause = cause
+
+    def __str__(self):
+        return self.message or self.cause.message
+
 class EnvError(Exception):
     """
     Thrown when the environment is incomplete or corrupted.
